@@ -1,4 +1,4 @@
--- This file is part of Quipper. Copyright (C) 2011-2014. Please see the
+-- This file is part of Quipper. Copyright (C) 2011-2016. Please see the
 -- file COPYRIGHT for a list of authors, copyright holders, licensing,
 -- and other details. All rights reserved.
 -- 
@@ -616,11 +616,6 @@ stepEvalCirc = do
               case all_ws_neg of
                 [] -> do
                    
-                   case g of
-                     NoOp -> error "stepEvalCirc cannot deal with NoOp"
-
-                     Init _ _ -> error "this is not supposed to arrive: a cnot became an init" -- setExpMap m_after
-                     Cnot w ctls -> do
                        -- There is no "simple" copy-cat...
                        -- Let's try to find a hidden one.
                        
